@@ -11,7 +11,7 @@ class Anzeige {
   void male();
   void setzeStossStaerke(GLfloat);
  private:
-  GLint AusschlagIndex;
+  //GLint AusschlagIndex;
   GLfloat StossStaerke;
 };
 
