@@ -7,11 +7,11 @@ void WeissneuHandling();
 void MenuHandling();
 void SchiedsrichterHandling();
 
-extern GLint Taste_Pfeil_Oben,Taste_Pfeil_Unten,\
-  Taste_Pfeil_Rechts,Taste_Pfeil_Links,Taste_Shift,\
-  Taste_Strg,Taste_Bild_Auf,Taste_Bild_Ab,Taste_Pos1,\
-  Taste_Ende,Faktor,AusholStartzeit,Startzeit,\
-  Stossdauer,StateMaschin,FrameZeitpunkt,Anfangsstoss,\
+extern GLint Taste_Pfeil_Oben,Taste_Pfeil_Unten,
+  Taste_Pfeil_Rechts,Taste_Pfeil_Links,Taste_Shift,
+  Taste_Strg,Taste_Bild_Auf,Taste_Bild_Ab,Taste_Pos1,
+  Taste_Ende,Faktor,AusholStartzeit,Startzeit,
+  Stossdauer,StateMaschin,FrameZeitpunkt,Anfangsstoss,
   WeisseVersetzbar;
 extern GLfloat MaxAusholStaerke,AusholStaerke;
 extern GLint   KugelnVersenkt[16];
