@@ -38,6 +38,11 @@
 /* --------- Konstruktor ---------- */
 Menu::Menu() {
   //
+  for (GLint TextfeldNr=0; TextfeldNr < 1000 ; TextfeldNr++ ) {
+    TextfeldArray[TextfeldNr] = 0;
+  }
+
+  TDL=0;
 }
 
 void Menu::Update(GLint Faktor) {
@@ -91,11 +96,11 @@ void Menu::ladeSprache(GLint Sprache) {
   FILE *f;
   char dateiname[1000];
 #ifndef _WIN32
-  sprintf(dateiname,"%s%i.lang",PFAD,Sprache);
+  sprintf(dateiname,"%slang/%i.lang",PFAD,Sprache);
   f=fopen(dateiname,"r");
 #endif
 #ifdef _WIN32
-  sprintf(dateiname,"%i.lang",Sprache);
+  sprintf(dateiname,"lang/%i.lang",Sprache);
   f=fopen(dateiname,"rb");
 #endif
   if (f) {
@@ -111,7 +116,7 @@ void Menu::ladeSprache(GLint Sprache) {
       while ((temp[--i]==10 || temp[i]==13 || temp[i]==32) && i) temp[i]=0;
       if (sscanf(temp,"%d %n",&nummer,&index)<1) continue;
 
-      printf("."); fflush(stdout);
+      //printf("."); fflush(stdout);
 
       i=0;
       while (temp[index+i]) {
@@ -133,15 +138,14 @@ void Menu::ladeSprache(GLint Sprache) {
   }
 }
 
-void Menu::Initialisiere(GLint Texturgroesse,GLint Nearest) {
+void Menu::Initialisiere(GLint Texturgroesse) {
 
-  for (GLint TextfeldNr=0; TextfeldNr < 1000 ; TextfeldNr++ ) {
-    TextfeldArray[TextfeldNr] = 0;
+  if (!TDL) { 
+    TDL=dummyTextfeld.dummyInitialisiere(Texturgroesse);
+    return;
   }
 
-  TDL=dummyTextfeld.dummyInitialisiere(Texturgroesse,Nearest);
-
-  printf(" Loading languages\n");
+  //printf(" Loading languages\n");
   ladeSprache(900); //Deutsch zuerst
   ladeSprache(901); //drueber Englisch als default
   ladeSprache(999); //Sprachenuebersicht
@@ -160,15 +164,15 @@ void Menu::Initialisiere(GLint Texturgroesse,GLint Nearest) {
     TextfeldArray[tf2]->SetzeMaxBreite(26);
   }
 
-  printf("\n\n Generating Menu Display Lists\n");
+  //printf("\n\n Generating Menu Display Lists\n");
 
   for (GLint dl=0 ; dl < 1000 ; dl++ ) {
     if (!TextfeldArray[dl]) continue;
     TextfeldArray[dl]->GeneriereDisplayList();
-    printf("."); fflush(stdout);
+    //printf("."); fflush(stdout);
   }
 
-  printf("\n\n");
+  //printf("\n\n");
 
   TextfeldArray[T_SPIELER1NAME]->SetzeText(Spieler1);
 
@@ -186,47 +190,51 @@ void Menu::Initialisiere(GLint Texturgroesse,GLint Nearest) {
   menuhintergrund.Initialisiere();
   SchildArray[SchildAnzahl++]=&menuhintergrund;
 
-  logo.Initialisiere(1,Nearest,"logo");
+  logo.InitialisiereLogo();
   SchildArray[SchildAnzahl++]=&logo;
 
-  ball[0].Initialisiere(1,Nearest,"a00","aalpha");
+  ball[0].Initialisiere(1,"a00","aalpha");
   SchildArray[SchildAnzahl++]=&ball[0];
-  ball[1].Initialisiere(1,Nearest,"a1","aalpha");
+  ball[1].Initialisiere(1,"a1","aalpha");
   SchildArray[SchildAnzahl++]=&ball[1];
-  ball[2].Initialisiere(1,Nearest,"a2","aalpha");
+  ball[2].Initialisiere(1,"a2","aalpha");
   SchildArray[SchildAnzahl++]=&ball[2];
-  ball[3].Initialisiere(1,Nearest,"a3","aalpha");
+  ball[3].Initialisiere(1,"a3","aalpha");
   SchildArray[SchildAnzahl++]=&ball[3];
-  ball[4].Initialisiere(1,Nearest,"a4","aalpha");
+  ball[4].Initialisiere(1,"a4","aalpha");
   SchildArray[SchildAnzahl++]=&ball[4];
-  ball[5].Initialisiere(1,Nearest,"a5","aalpha");
+  ball[5].Initialisiere(1,"a5","aalpha");
   SchildArray[SchildAnzahl++]=&ball[5];
-  ball[6].Initialisiere(1,Nearest,"a6","aalpha");
+  ball[6].Initialisiere(1,"a6","aalpha");
   SchildArray[SchildAnzahl++]=&ball[6];
-  ball[7].Initialisiere(1,Nearest,"a7","aalpha");
+  ball[7].Initialisiere(1,"a7","aalpha");
   SchildArray[SchildAnzahl++]=&ball[7];
-  ball[8].Initialisiere(1,Nearest,"a8","aalpha");
+  ball[8].Initialisiere(1,"a8","aalpha");
   SchildArray[SchildAnzahl++]=&ball[8];
-  ball[9].Initialisiere(1,Nearest,"a9","aalpha");
+  ball[9].Initialisiere(1,"a9","aalpha");
   SchildArray[SchildAnzahl++]=&ball[9];
-  ball[10].Initialisiere(1,Nearest,"a10","aalpha");
+  ball[10].Initialisiere(1,"a10","aalpha");
   SchildArray[SchildAnzahl++]=&ball[10];
-  ball[11].Initialisiere(1,Nearest,"a11","aalpha");
+  ball[11].Initialisiere(1,"a11","aalpha");
   SchildArray[SchildAnzahl++]=&ball[11];
-  ball[12].Initialisiere(1,Nearest,"a12","aalpha");
+  ball[12].Initialisiere(1,"a12","aalpha");
   SchildArray[SchildAnzahl++]=&ball[12];
-  ball[13].Initialisiere(1,Nearest,"a13","aalpha");
+  ball[13].Initialisiere(1,"a13","aalpha");
   SchildArray[SchildAnzahl++]=&ball[13];
-  ball[14].Initialisiere(1,Nearest,"a14","aalpha");
+  ball[14].Initialisiere(1,"a14","aalpha");
   SchildArray[SchildAnzahl++]=&ball[14];
-  ball[15].Initialisiere(1,Nearest,"a15","aalpha");
+  ball[15].Initialisiere(1,"a15","aalpha");
   SchildArray[SchildAnzahl++]=&ball[15];
 
-  volle.Initialisiere(Texturgroesse,Nearest,"volle","aalpha2");
+  volle.Initialisiere(Texturgroesse,"volle","aalpha2");
   SchildArray[SchildAnzahl++]=&volle;
-  halbe.Initialisiere(Texturgroesse,Nearest,"halbe","aalpha2");
+  halbe.Initialisiere(Texturgroesse,"halbe","aalpha2");
   SchildArray[SchildAnzahl++]=&halbe;
 
+  //GameStar.Initialisiere(1,"gamestar",1); //Gamestar
+  //SchildArray[SchildAnzahl++]=&GameStar;
+
+
   if (!MenuZustand) {MenuZustand=STARTBILDSCHIRM;}
 
   NeuerMenuZustand();
@@ -258,7 +266,7 @@ GLint Menu::Maustaste(int Taste,int Richtung,int x,int y){
     SignalAusfuehrung(Signal);
   }
 
-  if (MenuZustand==STARTBILDSCHIRM &&\
+  if (MenuZustand==STARTBILDSCHIRM &&
       Richtung==GLUT_UP) {
     if (Sprache) SetzeMenuZustand(HAUPTMENU);
     else SetzeMenuZustand(SPRACHAUSWAHL);
@@ -300,12 +308,21 @@ void Menu::NeuerMenuZustand(){
 
   case STARTBILDSCHIRM: {
 
-    logo.Positioniere(4,6,12,8);
-    logo.Positioniere(4,6,12,8);
+    //GameStar.Positioniere(6,5,10,6);
+    //GameStar.Positioniere(6,5,10,6);
+	  
+    logo.PositioniereFix(4,6,12,8);
+    //logo.Positioniere(4,6,12,8);
+
+	//TextfeldArray[790]->Positioniere(3.8,5,1,A_RECHTS);
+	//TextfeldArray[790]->Positioniere(3.8,5,1,A_RECHTS);
+	//TextfeldArray[791]->Positioniere(10.2,5,1,A_LINKS);
+	//TextfeldArray[791]->Positioniere(10.2,5,1,A_LINKS);
+
     TextfeldArray[T_NAMEN1]->Positioniere(8,1.4,.5,A_MITTE);
     TextfeldArray[T_NAMEN2]->Positioniere(8,1.0,.5,A_MITTE);
-    TextfeldArray[T_HOMEPAGE]->Positioniere(15.9,0,.5,A_RECHTS);
     TextfeldArray[T_NOWARRANTY]->Positioniere(8,0,.5,A_MITTE);
+    TextfeldArray[T_HOMEPAGE]->Positioniere(15.9,0,.5,A_RECHTS);
     TextfeldArray[T_VERSION]->Positioniere(.1,0,.5,A_LINKS);
 
   } break;
@@ -331,6 +348,8 @@ void Menu::NeuerMenuZustand(){
       TextfeldArray[T_ZURUECK]->Positioniere(8,1,1,A_MITTE);
       TextfeldArray[T_ZURUECK]->SetzeSignal(S_HM_EINSTELLUNGEN);
     }
+    TextfeldArray[T_HOMEPAGE]->Positioniere(15.9,0,.5,A_RECHTS);
+    TextfeldArray[T_VERSION]->Positioniere(.1,0,.5,A_LINKS);
   } break;
 
   case HAUPTMENU: {
@@ -359,6 +378,8 @@ void Menu::NeuerMenuZustand(){
     TextfeldArray[T_BEENDEN]->Positioniere(8,1,1,A_MITTE);
     TextfeldArray[T_BEENDEN]->SetzeSignal(S_HM_BEENDEN);
 
+    TextfeldArray[T_HOMEPAGE]->Positioniere(15.9,0,.5,A_RECHTS);
+    TextfeldArray[T_VERSION]->Positioniere(.1,0,.5,A_LINKS);
   } break;
 
   case TRAINING: {
@@ -379,6 +400,9 @@ void Menu::NeuerMenuZustand(){
 
     TextfeldArray[T_ZURUECK]->Positioniere(8,1,1,A_MITTE);
     TextfeldArray[T_ZURUECK]->SetzeSignal(S_TR_ZURUECK);
+
+    TextfeldArray[T_HOMEPAGE]->Positioniere(15.9,0,.5,A_RECHTS);
+    TextfeldArray[T_VERSION]->Positioniere(.1,0,.5,A_LINKS);
   } break;
 
   case ZWEISPIELER: {
@@ -401,6 +425,9 @@ void Menu::NeuerMenuZustand(){
     TextfeldArray[T_NEUNBALL]->SetzeSignal(S_ZW_NEUNBALL);
     TextfeldArray[T_ZURUECK]->Positioniere(8,1,1,A_MITTE);
     TextfeldArray[T_ZURUECK]->SetzeSignal(S_ZW_ZURUECK);
+
+    TextfeldArray[T_HOMEPAGE]->Positioniere(15.9,0,.5,A_RECHTS);
+    TextfeldArray[T_VERSION]->Positioniere(.1,0,.5,A_LINKS);
   } break;
 
   case EINSTELLUNGEN: {
@@ -422,6 +449,10 @@ void Menu::NeuerMenuZustand(){
     } else {
       TextfeldArray[T_ZURUECK]->SetzeSignal(S_EI_ZURUECK);
     }
+
+    TextfeldArray[T_HOMEPAGE]->Positioniere(15.9,0,.5,A_RECHTS);
+    TextfeldArray[T_VERSION]->Positioniere(.1,0,.5,A_LINKS);
+
   } break;
 
   case EINSTELLUNGENSTEUERUNG: {
@@ -478,6 +509,9 @@ void Menu::NeuerMenuZustand(){
       TextfeldArray[T_ABBRECHEN]->Positioniere(4,1,1,A_LINKS);
       TextfeldArray[T_ABBRECHEN]->SetzeSignal(S_EI_STEUERUNGZURUECK);
     }
+
+    TextfeldArray[T_HOMEPAGE]->Positioniere(15.9,0,.5,A_RECHTS);
+    TextfeldArray[T_VERSION]->Positioniere(.1,0,.5,A_LINKS);
   } break;
 
   case EINSTELLUNGENGRAFIK: {
@@ -489,8 +523,8 @@ void Menu::NeuerMenuZustand(){
 	E_BildschirmAufloesung==640 &&
 	E_Farbtiefe==16 &&
 	E_Schatten==0 &&
-	E_Nearest==1 &&
 	E_TischLampen==1 &&
+	E_TexMMM==0 &&
 	E_GrueneLampe==0) {Qualitaet=1;}
     else if (E_KugelAufloesung==5 &&
 	     E_Texturgroesse==4 &&
@@ -500,8 +534,8 @@ void Menu::NeuerMenuZustand(){
 	     E_BildschirmAufloesung==640 &&
 	     E_Farbtiefe==16 &&
 	     E_Schatten==1 &&
-	     E_Nearest==0 &&
 	     E_TischLampen==1 &&
+	     E_TexMMM==2 &&
 	     E_GrueneLampe==0) {Qualitaet=2;}
     else if (E_KugelAufloesung==7 &&
 	     E_Texturgroesse==2 &&
@@ -511,8 +545,8 @@ void Menu::NeuerMenuZustand(){
 	     E_BildschirmAufloesung==800 &&
 	     E_Farbtiefe==16 &&
 	     E_Schatten==1 &&
-	     E_Nearest==0 &&
 	     E_TischLampen==2 &&
+	     E_TexMMM==3 &&
 	     E_GrueneLampe==0) {Qualitaet=3;}
     else if (E_KugelAufloesung==7 &&
 	     E_Texturgroesse==2 &&
@@ -522,8 +556,8 @@ void Menu::NeuerMenuZustand(){
 	     E_BildschirmAufloesung==1024 &&
 	     E_Farbtiefe==16 &&
 	     E_Schatten==1 &&
-	     E_Nearest==0 &&
 	     E_TischLampen==2 &&
+	     E_TexMMM==7 &&
 	     E_GrueneLampe==1) {Qualitaet=4;}
     else if (E_KugelAufloesung==11 &&
 	     E_Texturgroesse==1 &&
@@ -533,8 +567,8 @@ void Menu::NeuerMenuZustand(){
 	     E_BildschirmAufloesung==1024 &&
 	     E_Farbtiefe==32 &&
 	     E_Schatten==1 &&
-	     E_Nearest==0 &&
 	     E_TischLampen==3 &&
+	     E_TexMMM==7 &&
 	     E_GrueneLampe==1) {Qualitaet=5;}
     else Qualitaet=0;
 
@@ -635,14 +669,23 @@ void Menu::NeuerMenuZustand(){
     } break;
     }
  
-    switch (E_Nearest) {
-    case 1: {
+    
+    switch (E_TexMMM) {
+    case 0: {
       TextfeldArray[T_TI_AUS]->Positioniere(8.2,3.3,.6,A_LINKS);
       TextfeldArray[T_TI_AUS]->SetzeSignal(S_EI_TEXTURINTERPOLATION);
     } break;
-    case 0: {
-      TextfeldArray[T_TI_EIN]->Positioniere(8.2,3.3,.6,A_LINKS);
-      TextfeldArray[T_TI_EIN]->SetzeSignal(S_EI_TEXTURINTERPOLATION);
+    case 2: {
+      TextfeldArray[T_TI_NIEDRIG]->Positioniere(8.2,3.3,.6,A_LINKS);
+      TextfeldArray[T_TI_NIEDRIG]->SetzeSignal(S_EI_TEXTURINTERPOLATION);
+    } break;
+    case 7: {
+      TextfeldArray[T_TI_HOCH]->Positioniere(8.2,3.3,.6,A_LINKS);
+      TextfeldArray[T_TI_HOCH]->SetzeSignal(S_EI_TEXTURINTERPOLATION);
+    } break;
+    default: {
+      TextfeldArray[T_TI_NORMAL]->Positioniere(8.2,3.3,.6,A_LINKS);
+      TextfeldArray[T_TI_NORMAL]->SetzeSignal(S_EI_TEXTURINTERPOLATION);
     } break;
     }
 
@@ -795,9 +838,9 @@ void Menu::NeuerMenuZustand(){
 	E_Farbtiefe==Farbtiefe &&
 	E_Reflektionen==Reflektionen &&
 	E_Schatten==Schatten &&
-	E_Nearest==Nearest &&
 	E_AmbientesLicht==AmbientesLicht &&
 	E_TischLampen==TischLampen &&
+	E_TexMMM==TexMMM &&
 	E_GrueneLampe==GrueneLampe) {
       TextfeldArray[T_ZURUECK]->Positioniere(8,.7,1,A_MITTE);
       TextfeldArray[T_ZURUECK]->SetzeSignal(S_EI_GRAFIKZURUECK);
@@ -807,6 +850,8 @@ void Menu::NeuerMenuZustand(){
       TextfeldArray[T_ABBRECHEN]->Positioniere(12,0.7,1,A_RECHTS);
       TextfeldArray[T_ABBRECHEN]->SetzeSignal(S_EI_GRAFIKZURUECK);
     }
+    TextfeldArray[T_HOMEPAGE]->Positioniere(15.9,0,.5,A_RECHTS);
+    TextfeldArray[T_VERSION]->Positioniere(.1,0,.5,A_LINKS);
   } break;
 
   case EINSTELLUNGENGRAFIKHINWEIS: {
@@ -821,6 +866,9 @@ void Menu::NeuerMenuZustand(){
 
     TextfeldArray[T_OK]->Positioniere(8,1,1,A_MITTE);
     TextfeldArray[T_OK]->SetzeSignal(S_EI_GRAFIKUEBERNEHMEN);
+
+    TextfeldArray[T_HOMEPAGE]->Positioniere(15.9,0,.5,A_RECHTS);
+    TextfeldArray[T_VERSION]->Positioniere(.1,0,.5,A_LINKS);
   } break;
 
   case HILFE: {
@@ -845,6 +893,10 @@ void Menu::NeuerMenuZustand(){
     } else {
       TextfeldArray[T_ZURUECK]->SetzeSignal(S_BE_ZURUECK);
     }
+
+    TextfeldArray[T_HOMEPAGE]->Positioniere(15.9,0,.5,A_RECHTS);
+    TextfeldArray[T_VERSION]->Positioniere(.1,0,.5,A_LINKS);
+
   } break;
 
   case HILFETASTENBELEGUNGEN: {
@@ -1111,10 +1163,14 @@ void Menu::NeuerMenuZustand(){
     } else {
       TextfeldArray[T_ZURUECK]->SetzeSignal(S_BE_ZURUECK);
     }
+
+    TextfeldArray[T_HOMEPAGE]->Positioniere(15.9,0,.5,A_RECHTS);
+    TextfeldArray[T_VERSION]->Positioniere(.1,0,.5,A_LINKS);
+
   } break;
 
   case AUSSPIEL: {
-    menuhintergrund.Positioniere(5.5,0.5,10.5,8.5);
+    menuhintergrund.Positioniere(3.5,0.5,12.5,8.5);
     logo.Positioniere(4,9,12,11);
     logo.VollSichtbar();
     TextfeldArray[T_WEITERSPIELEN]->Positioniere(8,7,1,A_MITTE);
@@ -1127,6 +1183,10 @@ void Menu::NeuerMenuZustand(){
     TextfeldArray[T_EINSTELLUNGEN]->SetzeSignal(S_AS_EINSTELLUNGEN);
     TextfeldArray[T_BEENDEN]->Positioniere(8,1,1,A_MITTE);
     TextfeldArray[T_BEENDEN]->SetzeSignal(S_AS_BEENDEN);
+
+    TextfeldArray[T_HOMEPAGE]->Positioniere(15.9,0,.5,A_RECHTS);
+    TextfeldArray[T_VERSION]->Positioniere(.1,0,.5,A_LINKS);
+
   } break;
   
   case SPIEL: {
@@ -1419,6 +1479,7 @@ void Menu::NeuerMenuZustand(){
 }
 
 void Menu::SignalAusfuehrung(GLint Signal) {
+  DelayAusgleich=1;
   switch (Signal) {
   case S_LOGO: {
     SetzeMenuZustand(STARTBILDSCHIRM);
@@ -1573,11 +1634,11 @@ void Menu::SignalAusfuehrung(GLint Signal) {
     E_Farbtiefe=Farbtiefe;
     E_Reflektionen=Reflektionen;
     E_Schatten=Schatten;
-    E_Nearest=Nearest;
     E_AmbientesLicht=AmbientesLicht;
     E_TischLampen=TischLampen;
     E_GrueneLampe=GrueneLampe;
     E_ZeigeFPS=ZeigeFPS;
+    E_TexMMM=TexMMM;
     SetzeMenuZustand(EINSTELLUNGENGRAFIK);
   } break;
   case S_EI_BALLTEXTUREN: {
@@ -1641,12 +1702,14 @@ void Menu::SignalAusfuehrung(GLint Signal) {
     SetzeMenuZustand(EINSTELLUNGENGRAFIK);
   } break;
   case S_EI_TEXTURINTERPOLATION: {
-    switch (E_Nearest) {
-    case 1: E_Nearest=0; break;
-    default:  E_Nearest=1; break;    
+    switch (E_TexMMM) {
+    case 0: E_TexMMM=7; break;
+    case 2: E_TexMMM=0; break;
+    case 3: E_TexMMM=2; break;
+    default:  E_TexMMM=3; break;    
     }
     SetzeMenuZustand(EINSTELLUNGENGRAFIK);
-  } break;
+    } break;
   case S_EI_AMBIENTESLICHT: {
     switch (E_AmbientesLicht) {
     case 1: E_AmbientesLicht=0; break;
@@ -1749,9 +1812,9 @@ void Menu::SignalAusfuehrung(GLint Signal) {
       E_BildschirmAufloesung=1024;
       E_Farbtiefe=32;
       E_Schatten=1;
-      E_Nearest=0;
       E_TischLampen=3;
       E_GrueneLampe=1;
+      E_TexMMM=7;
     } break;
     case 2: {
       E_KugelAufloesung=3;
@@ -1762,9 +1825,9 @@ void Menu::SignalAusfuehrung(GLint Signal) {
       E_BildschirmAufloesung=640;
       E_Farbtiefe=16;
       E_Schatten=0;
-      E_Nearest=1;     
       E_TischLampen=1;
       E_GrueneLampe=0;
+      E_TexMMM=0;
     } break;
     case 3: {
       E_KugelAufloesung=5;
@@ -1775,9 +1838,9 @@ void Menu::SignalAusfuehrung(GLint Signal) {
       E_BildschirmAufloesung=640;
       E_Farbtiefe=16;
       E_Schatten=1;
-      E_Nearest=0;
       E_TischLampen=1;
       E_GrueneLampe=0;
+      E_TexMMM=2;
     } break;
     case 4: {
       E_KugelAufloesung=7;
@@ -1788,9 +1851,9 @@ void Menu::SignalAusfuehrung(GLint Signal) {
       E_BildschirmAufloesung=800;
       E_Farbtiefe=16;
       E_Schatten=1;
-      E_Nearest=0;
       E_TischLampen=2;
       E_GrueneLampe=0;
+      E_TexMMM=3;
     } break;
     case 5: {
       E_KugelAufloesung=7;
@@ -1801,9 +1864,9 @@ void Menu::SignalAusfuehrung(GLint Signal) {
       E_BildschirmAufloesung=1024;
       E_Farbtiefe=16;
       E_Schatten=1;
-      E_Nearest=0;
       E_TischLampen=2;
       E_GrueneLampe=1;
+      E_TexMMM=7;
     } break;
     default: {
       E_KugelAufloesung=7;
@@ -1814,30 +1877,38 @@ void Menu::SignalAusfuehrung(GLint Signal) {
       E_BildschirmAufloesung=800;
       E_Farbtiefe=16;
       E_Schatten=1;
-      E_Nearest=0;
       E_TischLampen=2;
       E_GrueneLampe=0;
+      E_TexMMM=3;
     } break;
     }
     SetzeMenuZustand(EINSTELLUNGENGRAFIK);
   } break;
 
   case S_EI_GRAFIKUEBERNEHMEN: {
+
+    GLint TexMMMgeaendert=0;
+
+    if (TexMMM!=E_TexMMM) {
+      TexMMMgeaendert=1;
+      TexMMM=E_TexMMM;
+    }
+      
     if (Texturgroesse!=E_Texturgroesse ||
 	KugelAufloesung!=E_KugelAufloesung ||
-	Schatten!=E_Schatten||
-	Nearest!=E_Nearest) {
-
+	TexMMMgeaendert ||
+	Schatten!=E_Schatten) {
+      
       initialisiereKugelTabellen(E_KugelAufloesung);
-
+      
       for (GLint j=0;j<16;j++) {  // Initialisierung der Baelle + Laden der Texturen
-	Kugel[j].Initialisiere(j,E_Texturgroesse,E_KugelAufloesung,E_Nearest,E_Schatten);
+	Kugel[j].Initialisiere(j,E_Texturgroesse,E_KugelAufloesung,E_Schatten);
       }
     }
 
-    if (TischTexturgroesse!=E_TischTexturgroesse||
-	Nearest!=E_Nearest) {
-      Tisch.Initialisiere(E_TischTexturgroesse,E_Nearest);
+    if (TischTexturgroesse!=E_TischTexturgroesse ||
+	TexMMMgeaendert){
+      Tisch.Initialisiere(E_TischTexturgroesse);
     }
 
     if (Reflektionen!=E_Reflektionen ||
@@ -1847,9 +1918,9 @@ void Menu::SignalAusfuehrung(GLint Signal) {
       Beleuchtung.Initialisiere(E_AmbientesLicht,E_TischLampen,E_GrueneLampe,E_Reflektionen);
     }
 
-    if (AnzeigeTexturgroesse!=E_AnzeigeTexturgroesse ||
-	Nearest!=E_Nearest) {
-      Initialisiere(E_AnzeigeTexturgroesse,E_Nearest);
+    if (AnzeigeTexturgroesse!=E_AnzeigeTexturgroesse||
+	TexMMMgeaendert){
+      Initialisiere(E_AnzeigeTexturgroesse);
     }
 
     GLint NeueAufloesung=0;
@@ -1864,7 +1935,6 @@ void Menu::SignalAusfuehrung(GLint Signal) {
     BildschirmAufloesung=E_BildschirmAufloesung;
     Farbtiefe=E_Farbtiefe;
     Schatten=E_Schatten;
-    Nearest=E_Nearest;
     TischTexturgroesse=E_TischTexturgroesse;
     AmbientesLicht=E_AmbientesLicht;
     TischLampen=E_TischLampen;
@@ -1932,7 +2002,7 @@ void Menu::SignalAusfuehrung(GLint Signal) {
     SetzeMenuZustand(AUSSPIEL);
   } break;
   case S_SP_BALL+0: {
-    if (StateMaschin==BETRACHTEN ||\
+    if (StateMaschin==BETRACHTEN ||
 	StateMaschin==WEISSNEU) {
       Kamera.BlickeAuf3(Kugel[0].Pos_xCM(),Kugel[0].Pos_yCM());
     } else if (StateMaschin==STOSS) {
@@ -1940,7 +2010,7 @@ void Menu::SignalAusfuehrung(GLint Signal) {
     }
   } break;
   case S_SP_BALL+1: {
-    if (StateMaschin==BETRACHTEN ||\
+    if (StateMaschin==BETRACHTEN ||
 	StateMaschin==WEISSNEU) {
       Kamera.BlickeAuf3(Kugel[1].Pos_xCM(),Kugel[1].Pos_yCM());
     } else if (StateMaschin==STOSS) {
@@ -1948,7 +2018,7 @@ void Menu::SignalAusfuehrung(GLint Signal) {
     }
   } break;
   case S_SP_BALL+2: {
-    if (StateMaschin==BETRACHTEN ||\
+    if (StateMaschin==BETRACHTEN ||
 	StateMaschin==WEISSNEU) {
       Kamera.BlickeAuf3(Kugel[2].Pos_xCM(),Kugel[2].Pos_yCM());
     } else if (StateMaschin==STOSS) {
@@ -1956,7 +2026,7 @@ void Menu::SignalAusfuehrung(GLint Signal) {
     }
   } break;
   case S_SP_BALL+3: {
-    if (StateMaschin==BETRACHTEN ||\
+    if (StateMaschin==BETRACHTEN ||
 	StateMaschin==WEISSNEU) {
       Kamera.BlickeAuf3(Kugel[3].Pos_xCM(),Kugel[3].Pos_yCM());
     } else if (StateMaschin==STOSS) {
@@ -1964,7 +2034,7 @@ void Menu::SignalAusfuehrung(GLint Signal) {
     }
   } break;
   case S_SP_BALL+4: {
-    if (StateMaschin==BETRACHTEN ||\
+    if (StateMaschin==BETRACHTEN ||
 	StateMaschin==WEISSNEU) {
       Kamera.BlickeAuf3(Kugel[4].Pos_xCM(),Kugel[4].Pos_yCM());
     } else if (StateMaschin==STOSS) {
@@ -1972,7 +2042,7 @@ void Menu::SignalAusfuehrung(GLint Signal) {
     }
   } break;
   case S_SP_BALL+5: {
-    if (StateMaschin==BETRACHTEN ||\
+    if (StateMaschin==BETRACHTEN ||
 	StateMaschin==WEISSNEU) {
       Kamera.BlickeAuf3(Kugel[5].Pos_xCM(),Kugel[5].Pos_yCM());
     } else if (StateMaschin==STOSS) {
@@ -1980,7 +2050,7 @@ void Menu::SignalAusfuehrung(GLint Signal) {
     }
   } break;
   case S_SP_BALL+6: {
-    if (StateMaschin==BETRACHTEN ||\
+    if (StateMaschin==BETRACHTEN ||
 	StateMaschin==WEISSNEU) {
       Kamera.BlickeAuf3(Kugel[6].Pos_xCM(),Kugel[6].Pos_yCM());
     } else if (StateMaschin==STOSS) {
@@ -1988,7 +2058,7 @@ void Menu::SignalAusfuehrung(GLint Signal) {
     }
   } break;
   case S_SP_BALL+7: {
-    if (StateMaschin==BETRACHTEN ||\
+    if (StateMaschin==BETRACHTEN ||
 	StateMaschin==WEISSNEU) {
       Kamera.BlickeAuf3(Kugel[7].Pos_xCM(),Kugel[7].Pos_yCM());
     } else if (StateMaschin==STOSS) {
@@ -1996,7 +2066,7 @@ void Menu::SignalAusfuehrung(GLint Signal) {
     }
   } break;
   case S_SP_BALL+8: {
-    if (StateMaschin==BETRACHTEN ||\
+    if (StateMaschin==BETRACHTEN ||
 	StateMaschin==WEISSNEU) {
       Kamera.BlickeAuf3(Kugel[8].Pos_xCM(),Kugel[8].Pos_yCM());
     } else if (StateMaschin==STOSS) {
@@ -2004,7 +2074,7 @@ void Menu::SignalAusfuehrung(GLint Signal) {
     }
   } break;
   case S_SP_BALL+9: {
-    if (StateMaschin==BETRACHTEN ||\
+    if (StateMaschin==BETRACHTEN ||
 	StateMaschin==WEISSNEU) {
       Kamera.BlickeAuf3(Kugel[9].Pos_xCM(),Kugel[9].Pos_yCM());
     } else if (StateMaschin==STOSS) {
@@ -2012,7 +2082,7 @@ void Menu::SignalAusfuehrung(GLint Signal) {
     }
   } break;
   case S_SP_BALL+10: {
-    if (StateMaschin==BETRACHTEN ||\
+    if (StateMaschin==BETRACHTEN ||
 	StateMaschin==WEISSNEU) {
       Kamera.BlickeAuf3(Kugel[10].Pos_xCM(),Kugel[10].Pos_yCM());
     } else if (StateMaschin==STOSS) {
@@ -2020,7 +2090,7 @@ void Menu::SignalAusfuehrung(GLint Signal) {
     }
   } break;
   case S_SP_BALL+11: {
-    if (StateMaschin==BETRACHTEN ||\
+    if (StateMaschin==BETRACHTEN ||
 	StateMaschin==WEISSNEU) {
       Kamera.BlickeAuf3(Kugel[11].Pos_xCM(),Kugel[11].Pos_yCM());
     } else if (StateMaschin==STOSS) {
@@ -2028,7 +2098,7 @@ void Menu::SignalAusfuehrung(GLint Signal) {
     }
   } break;
   case S_SP_BALL+12: {
-    if (StateMaschin==BETRACHTEN ||\
+    if (StateMaschin==BETRACHTEN ||
 	StateMaschin==WEISSNEU) {
       Kamera.BlickeAuf3(Kugel[12].Pos_xCM(),Kugel[12].Pos_yCM());
     } else if (StateMaschin==STOSS) {
@@ -2036,7 +2106,7 @@ void Menu::SignalAusfuehrung(GLint Signal) {
     }
   } break;
   case S_SP_BALL+13: {
-    if (StateMaschin==BETRACHTEN ||\
+    if (StateMaschin==BETRACHTEN ||
 	StateMaschin==WEISSNEU) {
       Kamera.BlickeAuf3(Kugel[13].Pos_xCM(),Kugel[13].Pos_yCM());
     } else if (StateMaschin==STOSS) {
@@ -2044,7 +2114,7 @@ void Menu::SignalAusfuehrung(GLint Signal) {
     }
   } break;
   case S_SP_BALL+14: {
-    if (StateMaschin==BETRACHTEN ||\
+    if (StateMaschin==BETRACHTEN ||
 	StateMaschin==WEISSNEU) {
       Kamera.BlickeAuf3(Kugel[14].Pos_xCM(),Kugel[14].Pos_yCM());
     } else if (StateMaschin==STOSS) {
@@ -2052,7 +2122,7 @@ void Menu::SignalAusfuehrung(GLint Signal) {
     }
   } break;
   case S_SP_BALL+15: {
-    if (StateMaschin==BETRACHTEN ||\
+    if (StateMaschin==BETRACHTEN ||
 	StateMaschin==WEISSNEU) {
       Kamera.BlickeAuf3(Kugel[15].Pos_xCM(),Kugel[15].Pos_yCM());
     } else if (StateMaschin==STOSS) {
