@@ -19,7 +19,7 @@ GLfloat neuePos[16][3]; // neue Pos. der Kugeln
 
 GLfloat KugelSpeed[16][2]; // Geschw. Kugeln
 GLfloat FallFaktor = 25.0;
-GLfloat VerlustTasche = 0.9;
+GLfloat VerlustTasche = 1.0;
 
 // ---------------- Kugel versenken ----------------------------------------
 
@@ -101,7 +101,7 @@ void Kollision(GLfloat neu1[],GLfloat neu2[],GLint erste,GLint zweite){
 
   if (richtung < 0){
  
-    GLfloat skalarp = .9*(KugelSpeed[erste][0]*dx+KugelSpeed[erste][1]*dy)-\
+    GLfloat skalarp = .9*(KugelSpeed[erste][0]*dx+KugelSpeed[erste][1]*dy)-
       (KugelSpeed[zweite][0]*dx+KugelSpeed[zweite][1]*dy);
     GLfloat Kraftx = dx * skalarp;
     GLfloat Krafty = dy * skalarp;
@@ -297,6 +297,8 @@ void Physik(GLfloat Stoss_x,GLfloat Stoss_y) {
 		  xstrich = xstrich*VerlustTasche;
 		  KugelSpeed[i][0] = (xstrich * cos37 - ystrich * sin37);
 		  KugelSpeed[i][1] = (xstrich * sin37 + ystrich * cos37); 
+		  neuePos[i][0]+=KugelSpeed[i][0]/Aufloesung;
+		  neuePos[i][1]+=KugelSpeed[i][1]/Aufloesung;
 		}
 	      }
 	      // links
@@ -313,6 +315,8 @@ void Physik(GLfloat Stoss_x,GLfloat Stoss_y) {
 		  xstrich = xstrich*VerlustTasche;
 		  KugelSpeed[i][0] = (xstrich * cos37 - ystrich * sin37);
 		  KugelSpeed[i][1] = (xstrich * sin37 + ystrich * cos37); 
+		  neuePos[i][0]+=KugelSpeed[i][0]/Aufloesung;
+		  neuePos[i][1]+=KugelSpeed[i][1]/Aufloesung;
 		}
 	      }
 	      // Mitte rechts
@@ -329,6 +333,8 @@ void Physik(GLfloat Stoss_x,GLfloat Stoss_y) {
 		  xstrich = xstrich*VerlustTasche;
 		  KugelSpeed[i][0] = (xstrich * cos80 - ystrich * sin80);
 		  KugelSpeed[i][1] = (xstrich * sin80 + ystrich * cos80); 
+		  neuePos[i][0]+=KugelSpeed[i][0]/Aufloesung;
+		  neuePos[i][1]+=KugelSpeed[i][1]/Aufloesung;
 		}
 	      }
 	      // Mitte links
@@ -345,6 +351,8 @@ void Physik(GLfloat Stoss_x,GLfloat Stoss_y) {
 		  xstrich = xstrich*VerlustTasche;
 		  KugelSpeed[i][0] = (xstrich * cos80 - ystrich * sin80);
 		  KugelSpeed[i][1] = (xstrich * sin80 + ystrich * cos80); 
+		  neuePos[i][0]+=KugelSpeed[i][0]/Aufloesung;
+		  neuePos[i][1]+=KugelSpeed[i][1]/Aufloesung;
 		}
 	      }
 	    }
@@ -375,6 +383,8 @@ void Physik(GLfloat Stoss_x,GLfloat Stoss_y) {
 		  xstrich = xstrich*VerlustTasche;
 		  KugelSpeed[i][0] = (xstrich * cos37 - ystrich * sin37);
 		  KugelSpeed[i][1] = (xstrich * sin37 + ystrich * cos37); 
+		  neuePos[i][0]+=KugelSpeed[i][0]/Aufloesung;
+		  neuePos[i][1]+=KugelSpeed[i][1]/Aufloesung;
 		}
 	      }
 	      // links
@@ -391,7 +401,8 @@ void Physik(GLfloat Stoss_x,GLfloat Stoss_y) {
 		  xstrich = xstrich*VerlustTasche;
 		  KugelSpeed[i][0] = (xstrich * cos37 - ystrich * sin37);
 		  KugelSpeed[i][1] = (xstrich * sin37 + ystrich * cos37); 
-		  
+		  neuePos[i][0]+=KugelSpeed[i][0]/Aufloesung;
+		  neuePos[i][1]+=KugelSpeed[i][1]/Aufloesung;		  
 		}
 	      }
 	      // Mitte rechts
@@ -408,6 +419,8 @@ void Physik(GLfloat Stoss_x,GLfloat Stoss_y) {
 		  xstrich = xstrich*VerlustTasche;
 		  KugelSpeed[i][0] = (xstrich * cos80 - ystrich * sin80);
 		  KugelSpeed[i][1] = (xstrich * sin80 + ystrich * cos80); 
+		  neuePos[i][0]+=KugelSpeed[i][0]/Aufloesung;
+		  neuePos[i][1]+=KugelSpeed[i][1]/Aufloesung;
 		}
 	      }
 	      // Mitte links
@@ -424,6 +437,8 @@ void Physik(GLfloat Stoss_x,GLfloat Stoss_y) {
 		  xstrich = xstrich*VerlustTasche;
 		  KugelSpeed[i][0] = (xstrich * cos80 - ystrich * sin80);
 		  KugelSpeed[i][1] = (xstrich * sin80 + ystrich * cos80); 
+		  neuePos[i][0]+=KugelSpeed[i][0]/Aufloesung;
+		  neuePos[i][1]+=KugelSpeed[i][1]/Aufloesung;
 		}
 	      }
 	    }
@@ -454,6 +469,8 @@ void Physik(GLfloat Stoss_x,GLfloat Stoss_y) {
 		  xstrich = xstrich*VerlustTasche;
 		  KugelSpeed[i][0] = (xstrich * cos37 - ystrich * sin37);
 		  KugelSpeed[i][1] = (xstrich * sin37 + ystrich * cos37); 
+		  neuePos[i][0]+=KugelSpeed[i][0]/Aufloesung;
+		  neuePos[i][1]+=KugelSpeed[i][1]/Aufloesung;
 		}
 	      }
 	      // unten
@@ -470,6 +487,8 @@ void Physik(GLfloat Stoss_x,GLfloat Stoss_y) {
 		  xstrich = xstrich*VerlustTasche;
 		  KugelSpeed[i][0] = (xstrich * cos37 - ystrich * sin37);
 		  KugelSpeed[i][1] = (xstrich * sin37 + ystrich * cos37); 
+		  neuePos[i][0]+=KugelSpeed[i][0]/Aufloesung;
+		  neuePos[i][1]+=KugelSpeed[i][1]/Aufloesung;
 		}
 	      }
 	    }
@@ -500,6 +519,8 @@ void Physik(GLfloat Stoss_x,GLfloat Stoss_y) {
 		  xstrich = xstrich*VerlustTasche;
 		  KugelSpeed[i][0] = (xstrich * cos37 - ystrich * sin37);
 		  KugelSpeed[i][1] = (xstrich * sin37 + ystrich * cos37); 
+		  neuePos[i][0]+=KugelSpeed[i][0]/Aufloesung;
+		  neuePos[i][1]+=KugelSpeed[i][1]/Aufloesung;
 		}
 	      }
 	      // unten
@@ -516,6 +537,8 @@ void Physik(GLfloat Stoss_x,GLfloat Stoss_y) {
 		  xstrich = xstrich*VerlustTasche;
 		  KugelSpeed[i][0] = (xstrich * cos37 - ystrich * sin37);
 		  KugelSpeed[i][1] = (xstrich * sin37 + ystrich * cos37); 
+		  neuePos[i][0]+=KugelSpeed[i][0]/Aufloesung;
+		  neuePos[i][1]+=KugelSpeed[i][1]/Aufloesung;
 		}
 	      }
 	    }
