@@ -3,12 +3,14 @@ class Schild {
  public:
   Schild();
   void Initialisiere();
-  void Initialisiere(GLint,GLint,char[]);
-  void InitialisiereBuchstabe(GLint,GLint,char[]);
-  void Initialisiere(GLint,GLint,char[],char);
-  void Initialisiere(GLint,GLint,char[],char[]);
+  void InitialisiereLogo();
+  void Initialisiere(GLint,char[]);
+  void InitialisiereBuchstabe(GLint,char[]);
+  void Initialisiere(GLint,char[],char);
+  void Initialisiere(GLint,char[],char[]);
   void male();
   void Positioniere(GLfloat,GLfloat,GLfloat,GLfloat);
+  void PositioniereFix(GLfloat,GLfloat,GLfloat,GLfloat);
   void Desaktiviere();
   void Angewaehlt();
   void Eingeblendet();
@@ -32,6 +34,7 @@ class Schild {
   GLint InAnimation;
   GLint Signal;
   GLint Zeit;
+  GLuint Textur;
 };
 
 #define AUSGEBLENDET 0.0
@@ -42,3 +45,4 @@ class Schild {
 
 #define ANIMATIONSDAUER 100
 
+extern GLuint logotextur;
