@@ -1,12 +1,13 @@
 class Textfeld {
  public:
   Textfeld();
-  GLint dummyInitialisiere(GLint,GLint);
+  GLint dummyInitialisiere(GLint);
   void Initialisiere(GLint);
   void Initialisiere(GLint,char[]);
   void InitialisiereKDL(GLint,char[]);
   void male();
   void Positioniere(GLfloat,GLfloat,GLfloat,GLint);
+  void PositioniereFix(GLfloat,GLfloat,GLfloat,GLint);
   void SetzeText(char[]);
   void SetzeTextKDL(char[]);
   GLint Zeichen(char);
@@ -29,6 +30,8 @@ class Textfeld {
 
   void GeneriereDisplayList();
 
+  GLint dummyDisplayListAnfang();
+ 
  private:
   void StarteAnimation();
   char Zeichenkette[2000];
@@ -40,6 +43,7 @@ class Textfeld {
   GLint Signal;
   GLint Zeit; 
   GLint DisplayListAnfang;
+  GLuint TexturenAnfang[512];
   GLint TextfeldIndex;
   GLint Horchen;
   GLint Zeilen;
