@@ -1,4 +1,4 @@
-/****************************************************************************
+/***************************************************************************
 **
 **  Tisch.cpp   Stefan Disch, Tobias Nopper, Martina Welte 2001
 **
@@ -24,14 +24,17 @@ FMatrix woodtex_r,woodtex_g,woodtex_b;     // Matrix-Bilder, in die die Textur k
 
 
 Tisch::Tisch() {
-  /* */
+TischFlaechenTextur=0;
+HolzBandenTextur=0;
+
+	/* */
 }
 
 /* ----------------------
    Tisch initialisieren
    ---------------------- */
 
-void Tisch::Initialisiere(GLint Texturgroesse,GLint Nearest) {
+void Tisch::Initialisiere(GLint Texturgroesse) {
   if (!LinienIndex) {
     LinienIndex=glGenLists(1);      // Display List erzeugen
   }
@@ -475,9 +478,65 @@ void Tisch::Initialisiere(GLint Texturgroesse,GLint Nearest) {
   glEnd();
   glPopMatrix();
 
+  glBegin(GL_QUADS);
+
+  //Schattenrnder unter den Banden...
+  /*
+  glColor4f(0.0,0.0,0.0,0.0);
+  glVertex3f(7.38,63.5,-2.8575);
+  glVertex3f(117.16,63.5,-2.8575);
+  glColor4f(0.0,0.0,0.0,.4);
+  glVertex3f(128.3,68.5,-2.8575);
+  glVertex3f(6.5,68.5,-2.8575);
+  */
+  glColor4f(0.0,0.0,0.0,0.0);
+  glVertex3f(-139,65,-2.8575);
+  glVertex3f(139,65,-2.8575);
+  glColor4f(0.0,0.0,0.0,.6);
+  glVertex3f(139,68.5,-2.8575);
+  glVertex3f(-139,68.5,-2.8575);
+
+  glColor4f(0.0,0.0,0.0,0.0);
+  glVertex3f(139,-65,-2.8575);
+  glVertex3f(-139,-65,-2.8575);
+  glColor4f(0.0,0.0,0.0,.6);
+  glVertex3f(-139,-68.5,-2.8575);
+  glVertex3f(139,-68.5,-2.8575);
+
+  glColor4f(0.0,0.0,0.0,0.0);
+  glVertex3f(128.5,65,-2.8575);
+  glVertex3f(128.5,-65,-2.8575);
+  glColor4f(0.0,0.0,0.0,.6);
+  glVertex3f(132,-65,-2.8575);
+  glVertex3f(132,65,-2.8575);
+
+  glColor4f(0.0,0.0,0.0,0.0);
+  glVertex3f(-128.5,-65,-2.8575);
+  glVertex3f(-128.5,65,-2.8575);
+  glColor4f(0.0,0.0,0.0,.6);
+  glVertex3f(-132,65,-2.8575);
+  glVertex3f(-132,-65,-2.8575);
+
+  glEnd();
+
+
   glEnable(GL_LIGHTING);
   glEndList();
 
+  if (!TischFlaechenTextur) 
+	glGenTextures(1,&TischFlaechenTextur);
+  
+  if (Texturgroesse && Texturgroesse<8) {
+    GLint T=Texturgroesse;
+    if (T==4) T=2;
+    char Name[40];
+    sprintf(Name,"Texturen/%i/filzkachel.bmp",T); 
+    loadBMP(woodtex_r,woodtex_g,woodtex_b,Name);
+    glBindTexture(GL_TEXTURE_2D,TischFlaechenTextur);
+    createTextureMipmap(woodtex_r,woodtex_g,woodtex_b);
+  }
+  
+  
   if (!TischFlaecheIndex) {
     TischFlaecheIndex=glGenLists(1);      // Display List erzeugen
   }
@@ -489,14 +548,14 @@ void Tisch::Initialisiere(GLint Texturgroesse,GLint Nearest) {
   //Licht an:
   //Beleuchtung(0,0,1,0,0,Reflektionen);
 
-  GLfloat mat_ambient[]={0.1,0.45,0.2,1.0};
-  GLfloat mat_diffuse[]={0.1,0.45,0.2,1.0};
-  GLfloat mat_specular[]={0,0,0,1.0};
-  GLfloat mat_shininess = 0.0;
-  glMaterialfv(GL_FRONT, GL_AMBIENT,mat_ambient);
-  glMaterialfv(GL_FRONT, GL_DIFFUSE,mat_diffuse);
-  glMaterialfv(GL_FRONT, GL_SPECULAR,mat_specular);
-  glMaterialf(GL_FRONT, GL_SHININESS,mat_shininess);
+  //GLfloat mat_ambient[]={0.1,0.45,0.2,1.0};
+  //GLfloat mat_diffuse[]={0.1,0.45,0.2,1.0};
+  //GLfloat mat_specular[]={0,0,0,1.0};
+  //GLfloat mat_shininess = 0.0;
+  //glMaterialfv(GL_FRONT, GL_AMBIENT,mat_ambient);
+  //glMaterialfv(GL_FRONT, GL_DIFFUSE,mat_diffuse);
+  //glMaterialfv(GL_FRONT, GL_SPECULAR,mat_specular);
+  //glMaterialf(GL_FRONT, GL_SHININESS,mat_shininess);
 
 
   // Mae der Spielflche (in cm):
@@ -510,64 +569,147 @@ void Tisch::Initialisiere(GLint Texturgroesse,GLint Nearest) {
    Flaeche berechnen  
    ------------------------- */  
 
-  Tischflaeche();
+  if (Texturgroesse && Texturgroesse<8) {
 
+    GLfloat mat_ambient[]={1.0,1.0,1.0,1.0};
+    GLfloat mat_diffuse[]={1.0,1.0,1.0,1.0};
+    GLfloat mat_specular[]={0,0,0,1.0};
+    GLfloat mat_shininess = 0.0;
+    glMaterialfv(GL_FRONT, GL_AMBIENT,mat_ambient);
+    glMaterialfv(GL_FRONT, GL_DIFFUSE,mat_diffuse);
+    glMaterialfv(GL_FRONT, GL_SPECULAR,mat_specular);
+    glMaterialf(GL_FRONT, GL_SHININESS,mat_shininess);
+    glBindTexture(GL_TEXTURE_2D,TischFlaechenTextur);
+    glEnable(GL_TEXTURE_2D);
+    TischflaechemitTextur();
+    /* -------------
+       Lcher machen
+       ------------- */
+    
+    // unten links
+    glPushMatrix();
+    glTranslatef(-133.29,-69.79,0);
+    viertelLoch(widthx+1.3,widthy+1.3,4,4,.63,10,9.84,9.21,-133.29,-69.79,1,0,0,1); 
+    glPopMatrix();
+    
+    // unten Mitte 
+    glPushMatrix();
+    glTranslatef(0,-71.75,0);
+    viertelLoch(widthx+0.01,widthy+3.26,4,4,.63,10,7.62,6.99,0,-71.75,1,0,0,1);
+    glPopMatrix();
+    
+    glPushMatrix();
+    glTranslatef(0,-71.75,0);
+    glRotatef(90,0,0,1);
+    viertelLoch(widthy+3.26,widthx+0.01,4,4,.63,10.2,7.62,6.99,0,-71.75,0,-1,1,0);
+    glPopMatrix();
+    
+    //unten rechts   
+    glPushMatrix();
+    glTranslatef(133.29,-69.79,0); 
+    glRotatef(90,0,0,1);
+    viertelLoch(widthy+1.3,widthx+1.3,4,4,.63,10,9.84,9.21,133.29,-69.79,0,-1,-1,0); 
+    glPopMatrix();
+    
+    //oben rechts
+    glPushMatrix();
+    glTranslatef(133.29,69.79,0);
+    glRotatef(180,0,0,1);
+    viertelLoch(widthx+1.3,widthy+1.3,4,4,.63,10,9.84,9.21,133.29,69.79,-1,0,0,-1); 
+    glPopMatrix();
+    
+    //oben Mitte
+    glPushMatrix();
+    glTranslatef(0,71.75,0);
+    glRotatef(180,0,0,1);
+    viertelLoch(widthx+0.1,widthy+3.26,4,4,.63,10,7.62,6.99,0,71.75,-1,0,0,-1); 
+    glPopMatrix();
+    
+    glPushMatrix();
+    glTranslatef(0,71.75,0);
+    glRotatef(-90,0,0,1);
+    viertelLoch(widthy+3.26,widthx+0.1,4,4,.63,10,7.62,6.99,0,71.75,0,1,-1,0);
+    glPopMatrix();
+    
+    //oben links
+    glPushMatrix();
+    glTranslatef(-133.29,69.79,0); 
+    glRotatef(-90,0,0,1);
+    viertelLoch(widthy+1.3,widthx+1.3,4,4,.63,10,9.84,9.21,-133.29,69.79,0,1,-1,0); 
+    glPopMatrix();
+    glDisable(GL_TEXTURE_2D);
+    
+  } else {
+    
+    GLfloat mat_ambient[]={0.1,0.45,0.2,1.0};
+    GLfloat mat_diffuse[]={0.1,0.45,0.2,1.0};
+    GLfloat mat_specular[]={0,0,0,1.0};
+    GLfloat mat_shininess = 0.0;
+    glMaterialfv(GL_FRONT, GL_AMBIENT,mat_ambient);
+    glMaterialfv(GL_FRONT, GL_DIFFUSE,mat_diffuse);
+    glMaterialfv(GL_FRONT, GL_SPECULAR,mat_specular);
+    glMaterialf(GL_FRONT, GL_SHININESS,mat_shininess);
+    
 
-/* -------------
-   Lcher machen
-   ------------- */
+    Tischflaeche();
+    
+    /* -------------
+       Lcher machen
+       ------------- */
+    
+    // unten links
+    glPushMatrix();
+    glTranslatef(-133.29,-69.79,0);
+    viertelLoch(widthx+1.3,widthy+1.3,4,4,.63,10,9.84,9.21); 
+    glPopMatrix();
+    
+    // unten Mitte 
+    glPushMatrix();
+    glTranslatef(0,-71.75,0);
+    viertelLoch(widthx+0.01,widthy+3.26,4,4,.63,10,7.62,6.99);
+    glPopMatrix();
+    
+    glPushMatrix();
+    glTranslatef(0,-71.75,0);
+    glRotatef(90,0,0,1);
+    viertelLoch(widthy+3.26,widthx+0.01,4,4,.63,10.2,7.62,6.99);
+    glPopMatrix();
+    
+    //unten rechts   
+    glPushMatrix();
+    glTranslatef(133.29,-69.79,0); 
+    glRotatef(90,0,0,1);
+    viertelLoch(widthy+1.3,widthx+1.3,4,4,.63,10,9.84,9.21); 
+    glPopMatrix();
+    
+    //oben rechts
+    glPushMatrix();
+    glTranslatef(133.29,69.79,0);
+    glRotatef(180,0,0,1);
+    viertelLoch(widthx+1.3,widthy+1.3,4,4,.63,10,9.84,9.21); 
+    glPopMatrix();
+    
+    //oben Mitte
+    glPushMatrix();
+    glTranslatef(0,71.75,0);
+    glRotatef(180,0,0,1);
+    viertelLoch(widthx+0.1,widthy+3.26,4,4,.63,10,7.62,6.99); 
+    glPopMatrix();
+    
+    glPushMatrix();
+    glTranslatef(0,71.75,0);
+    glRotatef(-90,0,0,1);
+    viertelLoch(widthy+3.26,widthx+0.1,4,4,.63,10,7.62,6.99);
+    glPopMatrix();
+    
+    //oben links
+    glPushMatrix();
+    glTranslatef(-133.29,69.79,0); 
+    glRotatef(-90,0,0,1);
+    viertelLoch(widthy+1.3,widthx+1.3,4,4,.63,10,9.84,9.21); 
+    glPopMatrix();
 
-  // unten links
-  glPushMatrix();
-  glTranslatef(-133.29,-69.79,0);
-  viertelLoch(widthx+1.3,widthy+1.3,4,4,.63,10,9.84,9.21); 
-  glPopMatrix();
-
-  // unten Mitte 
-  glPushMatrix();
-  glTranslatef(0,-71.75,0);
-  viertelLoch(widthx+0.01,widthy+3.26,4,4,.63,10,7.62,6.99);
-  glPopMatrix();
-  
-  glPushMatrix();
-  glTranslatef(0,-71.75,0);
-  glRotatef(90,0,0,1);
-  viertelLoch(widthy+3.26,widthx+0.01,4,4,.63,10.2,7.62,6.99);
-  glPopMatrix();
-
-  //unten rechts   
-  glPushMatrix();
-  glTranslatef(133.29,-69.79,0); 
-  glRotatef(90,0,0,1);
-  viertelLoch(widthy+1.3,widthx+1.3,4,4,.63,10,9.84,9.21); 
-  glPopMatrix();
-      
-  //oben rechts
-  glPushMatrix();
-  glTranslatef(133.29,69.79,0);
-  glRotatef(180,0,0,1);
-  viertelLoch(widthx+1.3,widthy+1.3,4,4,.63,10,9.84,9.21); 
-  glPopMatrix();
-
-  //oben Mitte
-  glPushMatrix();
-  glTranslatef(0,71.75,0);
-  glRotatef(180,0,0,1);
-  viertelLoch(widthx+0.1,widthy+3.26,4,4,.63,10,7.62,6.99); 
-  glPopMatrix();
- 
-  glPushMatrix();
-  glTranslatef(0,71.75,0);
-  glRotatef(-90,0,0,1);
-  viertelLoch(widthy+3.26,widthx+0.1,4,4,.63,10,7.62,6.99);
-  glPopMatrix();
-
-  //oben links
-  glPushMatrix();
-  glTranslatef(-133.29,69.79,0); 
-  glRotatef(-90,0,0,1);
-  viertelLoch(widthy+1.3,widthx+1.3,4,4,.63,10,9.84,9.21); 
-  glPopMatrix();
+  }
 
   glPopMatrix();
   glEndList();
@@ -579,6 +721,18 @@ void Tisch::Initialisiere(GLint Texturgroesse,GLint Nearest) {
    Banden berechnen 
    -------------------- */
 
+  if (!HolzBandenTextur) 
+	glGenTextures(1,&HolzBandenTextur);
+
+  if (Texturgroesse) {
+    char Name[40];
+    sprintf(Name,"Texturen/%i/holz.bmp",Texturgroesse); 
+      
+    loadBMP(woodtex_r,woodtex_g,woodtex_b,Name);
+    glBindTexture(GL_TEXTURE_2D,HolzBandenTextur);
+    //createTextureMipmap(woodtex_r,woodtex_g,woodtex_b);
+    createTexture(woodtex_r,woodtex_g,woodtex_b);
+  }
 
   if (!BandenIndex) {
     BandenIndex=glGenLists(1);      // Display List erzeugen
@@ -588,7 +742,7 @@ void Tisch::Initialisiere(GLint Texturgroesse,GLint Nearest) {
     GLfloat mat_ambient[]={0.1,0.45,0.2,1.0};
     GLfloat mat_diffuse[]={0.1,0.45,0.2,1.0};
     GLfloat mat_specular[]={0,0,0,1.0};
-    GLfloat mat_shininess = 0.0;
+    GLfloat mat_shininess = 127.0;
     glMaterialfv(GL_FRONT, GL_AMBIENT,mat_ambient);
     glMaterialfv(GL_FRONT, GL_DIFFUSE,mat_diffuse);
     glMaterialfv(GL_FRONT, GL_SPECULAR,mat_specular);
@@ -707,11 +861,12 @@ void Tisch::Initialisiere(GLint Texturgroesse,GLint Nearest) {
     
     //Holzbanden
     if (Texturgroesse) {
-      char Name[40];
-      sprintf(Name,"Texturen/%i/holz.bmp",Texturgroesse); 
+      //char Name[40];
+      //sprintf(Name,"Texturen/%i/holz.bmp",Texturgroesse); 
       
-      loadBMP(woodtex_r,woodtex_g,woodtex_b,Name);
-      createWoodTexture(woodtex_r,woodtex_g,woodtex_b,Nearest);
+      //loadBMP(woodtex_r,woodtex_g,woodtex_b,Name);
+      //createWoodTexture(woodtex_r,woodtex_g,woodtex_b,Nearest);
+      glBindTexture(GL_TEXTURE_2D,HolzBandenTextur);
       glEnable(GL_TEXTURE_2D);
       glTexEnvf(GL_TEXTURE_ENV,GL_TEXTURE_ENV_MODE,GL_MODULATE);
       
@@ -788,7 +943,7 @@ void Tisch::Initialisiere(GLint Texturgroesse,GLint Nearest) {
       
       GLfloat mat_diffuse[]={1.0,1.0,1.0,1.0};
       GLfloat mat_specular[]={1.0,1.0,1.0,1.0};
-      GLfloat mat_shininess = 127.0;
+      GLfloat mat_shininess = 0.0;
 
       glMaterialfv(GL_FRONT, GL_AMBIENT,mat_diffuse);
       glMaterialfv(GL_FRONT, GL_DIFFUSE,mat_diffuse);
