@@ -9,7 +9,7 @@
 class Tisch {
  public:
   Tisch();
-  void Initialisiere(GLint,GLint);
+  void Initialisiere(GLint);
   void maleFlaeche();
   void maleBanden();
   void maleLinien();
@@ -17,6 +17,8 @@ class Tisch {
   GLint TischFlaecheIndex;
   GLint BandenIndex;
   GLint LinienIndex;
+  GLuint TischFlaechenTextur;
+  GLuint HolzBandenTextur;
 };
 
 
